package com.rhiannonweb.android.migrainetracker.data;

import java.util.ArrayList;
import java.util.List;

import android.content.Context;
import android.database.Cursor;
import android.database.DataSetObserver;
import android.database.sqlite.SQLiteDatabase;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ListAdapter;
import android.widget.TextView;

import com.rhiannonweb.android.migrainetracker.R;

public class HeadacheListAdapter implements ListAdapter {
	private List<Headache> headaches = new ArrayList<Headache>();
	private Context context;
	
	public HeadacheListAdapter(Context context) {
		super();
		this.context = context;
		
		SQLiteDatabase db = new MigraineOpen(context, MigraineOpen.HEADACHE_TABLE, null).getReadableDatabase();
		Cursor curses = db.query(MigraineOpen.HEADACHE_TABLE, MigraineOpen.COLUMNS, MigraineOpen.END_DATE + " IS NOT NULL", null, null, null, MigraineOpen.BEGIN_DATE);
		if (curses != null && curses.getCount() > 0) {
			curses.moveToFirst();
			while (curses.isAfterLast() == false) {
				headaches.add(new Headache(curses));
				curses.moveToNext();
			}
			curses.close();
		}
	}
	

	@Override
	public int getCount() {
		return headaches.size();
	}

	@Override
	public Object getItem(int arg0) {
		return headaches.get(arg0);
	}

	@Override
	public long getItemId(int arg0) {
		return headaches.get(arg0).getDbID();
	}

	@Override
	public int getItemViewType(int arg0) {
		return R.layout.headache_item;
	}

	@Override
	public View getView(int arg0, View arg1, ViewGroup arg2) {
		Headache owie = headaches.get(arg0);
		
		LayoutInflater inf = LayoutInflater.from(context);
		View rowView = inf.inflate(R.layout.headache_item, null, true);
		
		TextView beginDate = (TextView) rowView.findViewById(R.id.list_begin_date);
		beginDate.setText(owie.getBeginDate().toLocaleString());
		
		TextView duration = (TextView) rowView.findViewById(R.id.list_duration);
		duration.setText(owie.getDuration());
		
		TextView severity = (TextView) rowView.findViewById(R.id.list_severity);
		severity.setText(owie.getSeverity() + "/10");
		
		return rowView;
	}

	@Override
	public int getViewTypeCount() {
		return 1;
	}

	@Override
	public boolean hasStableIds() {
		return true;
	}

	@Override
	public boolean isEmpty() {
		return headaches.isEmpty();
	}

	@Override
	public void registerDataSetObserver(DataSetObserver arg0) {
		// TODO Auto-generated method stub
		
	}

	@Override
	public void unregisterDataSetObserver(DataSetObserver arg0) {
		// TODO Auto-generated method stub
		
	}

	@Override
	public boolean areAllItemsEnabled() {
		return true;
	}

	@Override
	public boolean isEnabled(int position) {
		return true;
	}

}
