package com.rhiannonweb.android.migrainetracker.data;

import android.content.Context;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteDatabase.CursorFactory;
import android.database.sqlite.SQLiteOpenHelper;
import android.provider.BaseColumns;

public class MigraineOpen extends SQLiteOpenHelper {
	private static final int DATABASE_VERSION = 2;
	
	public static final String HEADACHE_TABLE = "headache";
	public static final String BEGIN_DATE = "beginDate";
	public static final String END_DATE = "endDate";
	public static final String SEVERITY = "severity";
	public static final String NOTES = "notes";
	public static final String[] COLUMNS = new String[] {BaseColumns._ID, BEGIN_DATE, END_DATE, SEVERITY, NOTES};
	
	public static final String DATE_FORMAT = "yyyy-MM-dd'T'HH:mm:ss";
	
	private static final String HEADACHE_TABLE_CREATE =
		"CREATE TABLE " + HEADACHE_TABLE + " (" +
		BaseColumns._ID + " INTEGER PRIMARY KEY NOT NULL, " +
		BEGIN_DATE + " TIMESTAMP NOT NULL, " +
		END_DATE + " TIMESTAMP, " +
		SEVERITY + " INTEGER, " +
		NOTES + " TEXT DEFAULT ''" +
		");";

	public MigraineOpen(Context context, String name, CursorFactory factory) {
		super(context, name, factory, DATABASE_VERSION);
	}

	@Override
	public void onCreate(SQLiteDatabase db) {
		db.execSQL(HEADACHE_TABLE_CREATE);
	}

	@Override
	public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
		if (oldVersion < 1 && newVersion == DATABASE_VERSION) {
			onCreate(db);
			return;
		}
		
		switch (oldVersion) {
		case 1:
			upgrade1To2(db);
		default:
			break;
		}
	}
	
	private void upgrade1To2(SQLiteDatabase db) {
		String alterQuery = "ALTER TABLE " +  HEADACHE_TABLE + " ADD COLUMN " + NOTES + " TEXT DEFAULT '';";
		db.execSQL(alterQuery);
	}
}
