package com.rhiannonweb.android.migrainetracker.ui;

import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.database.sqlite.SQLiteDatabase;
import android.provider.BaseColumns;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.RatingBar;
import android.widget.TextView;

import com.rhiannonweb.android.migrainetracker.R;
import com.rhiannonweb.android.migrainetracker.data.Headache;
import com.rhiannonweb.android.migrainetracker.data.MigraineOpen;

public class DetailsDialog extends Dialog {
	private Headache ouch;

	public DetailsDialog(Context context, Headache owie) {
		super(context);
		ouch = owie;
		setupLayout();
	}

	public DetailsDialog(Context context, int theme, Headache owie) {
		super(context, theme);
		ouch = owie;
		setupLayout();
	}

	public DetailsDialog(Context context, boolean cancelable,
			OnCancelListener cancelListener, Headache owie) {
		super(context, cancelable, cancelListener);
		ouch = owie;
		setupLayout();
	}
	
	private void setupLayout() {
		this.setContentView(R.layout.details_dialog);
		setTitle(R.string.dialog_title);
		
		TextView start = (TextView) findViewById(R.id.start_datetime);
		start.setText(ouch.getBeginDate().toLocaleString());
		
		TextView end = (TextView) findViewById(R.id.end_datetime);
		end.setText(ouch.getEndDate().toLocaleString());
		
		TextView duration = (TextView) findViewById(R.id.duration);
		duration.setText(ouch.getDuration());
		
		EditText notes = (EditText) findViewById(R.id.notes);
		notes.setText(ouch.getNotes());
		
		this.setOnDismissListener(new OnDismissListener() {

			@Override
			public void onDismiss(DialogInterface arg0) {
				// Pull in editable data from form into backing structure.
				RatingBar bar = (RatingBar) findViewById(R.id.severity_bar);
				ouch.setSeverity(Math.round(bar.getRating() * 2));
				EditText notes = (EditText) findViewById(R.id.notes);
				ouch.setNotes(notes.getText().toString());
				
				SQLiteDatabase db = null;
				try {
					db = new MigraineOpen(getContext(), MigraineOpen.HEADACHE_TABLE, null).getWritableDatabase();
					if (ouch.getDbID() <= 0) {
						ouch.setDbID(db.insert(MigraineOpen.HEADACHE_TABLE, null, ouch.getSQLContentValues()));
					} else {
						db.update(MigraineOpen.HEADACHE_TABLE, ouch.getSQLContentValues(), BaseColumns._ID + " = ?", new String[]{ouch.getDbID() + ""});
					}
				} catch (Exception e) {
					Log.e(this.getClass().getCanonicalName(), "Error inserting or updating the record " + ouch, e);
				} finally {
					if (db != null && db.isOpen()) {
						db.close();
					}
				}
			}
			
		});
		
		Button ok = (Button) findViewById(R.id.okButton);
		ok.setClickable(true);
		ok.setOnClickListener(new View.OnClickListener() {

			@Override
			public void onClick(View v) {
				DetailsDialog.this.dismiss();
			}
			
		});
	}

}
